@@ -8,10 +8,10 @@ from pythonwrench.typing.checks import is_dataclass_instance  # noqa: F401
 from pythonwrench.typing.classes import DataclassInstance
 
 
-def get_defaults_values(dataclass: DataclassInstance) -> Dict[str, Any]:
+def get_defaults_values(obj: DataclassInstance) -> Dict[str, Any]:
     defaults = {}
 
-    for field in dataclass.__dataclass_fields__.values():
+    for field in obj.__dataclass_fields__.values():
         if callable(field.default_factory):
             default = field.default_factory()
         else:
