@@ -5,13 +5,20 @@ import importlib
 import json
 import logging
 import sys
+from functools import wraps
 from importlib.metadata import Distribution, PackageNotFoundError
 from importlib.util import find_spec
 from types import ModuleType
-from typing import Any, Dict, List
+from typing import Any, Callable, Dict, Iterable, List, Union
+
+from typing_extensions import ParamSpec, TypeVar
 
 from pythonwrench.warnings import warn_once
 
+P = ParamSpec("P")
+T = TypeVar("T")
+
+
 _DEFAULT_SKIPPED = (
     "reimport_all",
     "get_ipython",
@@ -32,9 +39,8 @@ logger = logging.getLogger(__name__)
 def is_available_package(package: str) -> bool:
     """Returns True if package is installed in the current python environment."""
     if "-" in package:
-        warn_once(
-            f"Found character '-' in package name '{package}'. (it will be replaced by '_')"
-        )
+        msg = f"Found character '-' in package name '{package}'. (it will be replaced by '_')"
+        warn_once(msg)
         package = package.replace("-", "_")
 
     try:
@@ -162,3 +168,44 @@ class Placeholder:
 
     def __getitem__(self, *args, **kwargs) -> Any:
         return self
+
+
+def requires_packages(
+    arg0: Union[Iterable[str], str],
+    /,
+    *args: str,
+) -> Callable[[Callable[P, T]], Callable[P, T]]:
+    """Decorator to wrap a function and raises an error if the function is called.
+
+    ```
+    >>> @requires_packages("pandas")
+    >>> def f(x):
+    >>>     return x
+    >>> f(1)  # raises ImportError if pandas is not installed
+    ```
+    """
+    if isinstance(arg0, str):
+        packages = [arg0] + list(args)
+    elif isinstance(arg0, Iterable):
+        packages = list(arg0) + list(args)
+    else:
+        raise TypeError(f"Invalid arguments types {(arg0,) + args}.")
+
+    def _wrap(fn: Callable[P, T]) -> Callable[P, T]:
+        @wraps(fn)
+        def _impl(*args: P.args, **kwargs: P.kwargs) -> T:
+            missing = [pkg for pkg in packages if not is_available_package(pkg)]
+            if len(missing) == 0:
+                return fn(*args, **kwargs)
+            else:
+                prefix = "\n - "
+                missing_str = prefix.join(missing)
+                msg = (
+                    f"Cannot use/import objects because the following optionals dependencies are missing:"
+                    f"{prefix}{missing_str}\n"
+                )
+                raise ImportError(msg)
+
+        return _impl
+
+    return _wrap
