@@ -17,9 +17,12 @@ class TestChecksum(TestCase):
             list(range(10)),
             tuple(range(10)),
             set(range(10)),
+            frozenset(range(10)),
             range(10),
+            dict.fromkeys(range(10)),
             [],
             (),
+            {},
             None,
             0,
             1,
