@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import unittest
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, is_dataclass
 from typing import List, Tuple
 from unittest import TestCase
 
@@ -20,7 +20,12 @@ class Dummy:
 class TestDataclass(TestCase):
     def test_example_1(self) -> None:
         dummy = Dummy(2)
+
+        assert is_dataclass(dummy)
+        assert is_dataclass(Dummy)
         assert is_dataclass_instance(dummy)
+        assert not is_dataclass_instance(Dummy)
+
         assert get_defaults_values(dummy) == {"b": "b", "c": (), "d": []}
 
 
